summaryrefslogtreecommitdiffstats
path: root/cpukit/sapi
diff options
context:
space:
mode:
authorSebastian Huber <sebastian.huber@embedded-brains.de>2010-07-01 15:18:06 +0000
committerSebastian Huber <sebastian.huber@embedded-brains.de>2010-07-01 15:18:06 +0000
commit955a34b566dbd7076084dff82ec5468b9c6d8336 (patch)
tree1395933adfd0fcbeb17d6cbd0e9ce69afd72d242 /cpukit/sapi
parent2010-06-29 Sebastian Huber <sebastian.huber@embedded-brains.de> (diff)
downloadrtems-955a34b566dbd7076084dff82ec5468b9c6d8336.tar.bz2
2010-07-01 Sebastian Huber <sebastian.huber@embedded-brains.de>
* libcsupport/include/rtems/libio_.h: Removed rtems_filesystem_mount_table_control. * libcsupport/include/rtems/libio.h, libcsupport/src/mount-mgr.c, libcsupport/src/mount.c libcsupport/src/statvfs.c, libcsupport/src/unmount.c, libmisc/shell/main_mount.c: Documentation. Removed rtems_filesystem_mounts_first() and rtems_filesystem_mounts_next(). Added rtems_filesystem_mount_iterate(). Changed return type of rtems_filesystem_iterate(). Removed rtems_filesystem_nodes_equal(). 2010-07-01 Sebastian Huber <sebastian.huber@embedded-brains.de> * libfs/src/nfsclient/src/nfs.c, libfs/src/nfsclient/src/nfs.c, libfs/src/nfsclient/src/librtemsNfs.h: Renamed rtems_nfsfs_initialize() in rtems_nfs_initialize(). * sapi/include/confdefs.h: Reflect changes above. Renamed *_miniIMFS in *_MINIIMFS. Renamed *_NFSFS in *_NFS.
Diffstat (limited to 'cpukit/sapi')
-rw-r--r--cpukit/sapi/include/confdefs.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/cpukit/sapi/include/confdefs.h b/cpukit/sapi/include/confdefs.h
index 7df2851abc..9ee41435eb 100644
--- a/cpukit/sapi/include/confdefs.h
+++ b/cpukit/sapi/include/confdefs.h
@@ -188,12 +188,12 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
* Add file filesystems to the default filesystem table.
*
* List of available file systems. You can define as many as you like:
- * CONFIGURE_FILESYSTEM_miniIMFS - MiniIMFS, use DEVFS now
+ * CONFIGURE_FILESYSTEM_MINIIMFS - MiniIMFS, use DEVFS now
* CONFIGURE_FILESYSTEM_IMFS - In Memory File System (IMFS)
* CONFIGURE_FILESYSTEM_DEVFS - Device File System (DSVFS)
* CONFIGURE_FILESYSTEM_TFTPFS - TFTP File System, networking enabled
* CONFIGURE_FILESYSTEM_FTPFS - FTP File System, networking enabled
* CONFIGURE_FILESYSTEM_NFSFS - Network File System, networking enabled
* CONFIGURE_FILESYSTEM_DOSFS - DOS File System, uses libblock
* CONFIGURE_FILESYSTEM_RFS - RTEMS File System (RFS), uses libblock
*
@@ -215,12 +215,12 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
* been disabled.
*/
#ifdef CONFIGURE_FILESYSTEM_ALL
- #define CONFIGURE_FILESYSTEM_miniIMFS
+ #define CONFIGURE_FILESYSTEM_MINIIMFS
#define CONFIGURE_FILESYSTEM_IMFS
#define CONFIGURE_FILESYSTEM_DEVFS
#define CONFIGURE_FILESYSTEM_TFTPFS
#define CONFIGURE_FILESYSTEM_FTPFS
- #define CONFIGURE_FILESYSTEM_NFSFS
+ #define CONFIGURE_FILESYSTEM_NFS
#define CONFIGURE_FILESYSTEM_DOSFS
#define CONFIGURE_FILESYSTEM_RFS
#endif
@@ -239,12 +239,12 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
#elif defined(CONFIGURE_USE_DEVFS_AS_BASE_FILESYSTEM)
#undef CONFIGURE_USE_MINIIMFS_AS_BASE_FILESYSTEM
#endif
- #undef CONFIGURE_FILESYSTEM_miniIMFS
+ #undef CONFIGURE_FILESYSTEM_MINIIMFS
#undef CONFIGURE_FILESYSTEM_IMFS
#undef CONFIGURE_FILESYSTEM_DEVFS
#undef CONFIGURE_FILESYSTEM_TFTPFS
#undef CONFIGURE_FILESYSTEM_FTPFS
- #undef CONFIGURE_FILESYSTEM_NFSFS
+ #undef CONFIGURE_FILESYSTEM_NFS
#undef CONFIGURE_FILESYSTEM_DOSFS
#undef CONFIGURE_FILESYSTEM_RFS
#endif
@@ -257,7 +257,7 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
#if defined(CONFIGURE_USE_DEVFS_AS_BASE_FILESYSTEM)
#define CONFIGURE_FILESYSTEM_DEVFS
#elif defined(CONFIGURE_USE_MINIIMFS_AS_BASE_FILESYSTEM)
- #define CONFIGURE_FILESYSTEM_miniIMFS
+ #define CONFIGURE_FILESYSTEM_MINIIMFS
#elif !defined(CONFIGURE_FILESYSTEM_IMFS)
#define CONFIGURE_FILESYSTEM_IMFS
#endif
@@ -285,7 +285,7 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
* This defines the miniIMFS file system table entry.
*/
#if !defined(CONFIGURE_FILESYSTEM_ENTRY_miniIMFS) && \
- defined(CONFIGURE_FILESYSTEM_miniIMFS)
+ defined(CONFIGURE_FILESYSTEM_MINIIMFS)
#define CONFIGURE_FILESYSTEM_ENTRY_miniIMFS \
{ RTEMS_FILESYSTEM_TYPE_MINIIMFS, miniIMFS_initialize }
#endif
@@ -330,13 +330,13 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
#endif
/**
- * NFSFS
+ * NFS
*/
- #if !defined(CONFIGURE_FILESYSTEM_ENTRY_NFSFS) && \
- defined(CONFIGURE_FILESYSTEM_NFSFS)
+ #if !defined(CONFIGURE_FILESYSTEM_ENTRY_NFS) && \
+ defined(CONFIGURE_FILESYSTEM_NFS)
#include <librtemsNfs.h>
- #define CONFIGURE_FILESYSTEM_ENTRY_NFSFS \
- { RTEMS_FILESYSTEM_TYPE_NFS, rtems_nfsfs_initialize }
+ #define CONFIGURE_FILESYSTEM_ENTRY_NFS \
+ { RTEMS_FILESYSTEM_TYPE_NFS, rtems_nfs_initialize }
#endif
#endif
@@ -381,7 +381,7 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
#endif
#if defined(CONFIGURE_FILESYSTEM_IMFS) || \
- defined(CONFIGURE_FILESYSTEM_miniIMFS)
+ defined(CONFIGURE_FILESYSTEM_MINIIMFS)
int imfs_rq_memfile_bytes_per_block = CONFIGURE_IMFS_MEMFILE_BYTES_PER_BLOCK;
#endif
@@ -396,7 +396,7 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
*/
#ifndef CONFIGURE_HAS_OWN_FILESYSTEM_TABLE
const rtems_filesystem_table_t rtems_filesystem_table[] = {
- #if defined(CONFIGURE_FILESYSTEM_miniIMFS) && \
+ #if defined(CONFIGURE_FILESYSTEM_MINIIMFS) && \
defined(CONFIGURE_FILESYSTEM_ENTRY_miniIMFS)
CONFIGURE_FILESYSTEM_ENTRY_miniIMFS,
#endif
@@ -416,9 +416,9 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
defined(CONFIGURE_FILESYSTEM_ENTRY_FTPFS)
CONFIGURE_FILESYSTEM_ENTRY_FTPFS,
#endif
- #if defined(CONFIGURE_FILESYSTEM_NFSFS) && \
- defined(CONFIGURE_FILESYSTEM_ENTRY_NFSFS)
- CONFIGURE_FILESYSTEM_ENTRY_NFSFS,
+ #if defined(CONFIGURE_FILESYSTEM_NFS) && \
+ defined(CONFIGURE_FILESYSTEM_ENTRY_NFS)
+ CONFIGURE_FILESYSTEM_ENTRY_NFS,
#endif
#if defined(CONFIGURE_FILESYSTEM_DOSFS) && \
defined(CONFIGURE_FILESYSTEM_ENTRY_DOSFS)
@@ -188,12 +188,12 @@ rtems_fs_init_functions_t rtems_fs_init_helper =
* CONFIGURE_FILESYSTEM_TFTPFS - TFTP File System, networking enabled
* CONFIGURE_FILESYSTEM_FTPFS - FTP File System, networking enabled
- * CONFIGURE_FILESYSTEM_NFSFS - Network File System, networking enabled
+ * CONFIGURE_FILESYSTEM_NFS - Network File System, networking enabled
* CONFIGURE_FILESYSTEM_DOSFS - DOS File System, uses libblock
* CONFIGURE_FILESYSTEM_RFS - RTEMS File System (RFS), uses libblock